package ch.sahits.game.openpatrician.model;

import java.io.IOException;

import ch.sahits.game.openpatrician.model.city.CityFactory;
import ch.sahits.game.openpatrician.model.city.ECityName;
import ch.sahits.game.openpatrician.model.city.ICity;

public class GameFactory {
	/**
	 * Create a human player instance
	 * @param name
	 * @param lastName
	 * @param homeTown
	 * @param male
	 * @return
	 */
	public static IPlayer createPlayer(String name, String lastName, ICity homeTown, boolean male, int cash) {
		return new Player(name, lastName, homeTown, male,cash);
	}
	/**
	 * Create an artifiacial player instance
	 * @param homeTown
	 * @return
	 */
	public static IPlayer createAIPlayer(ICity homeTown,int cash) {
		return new AIPlayer(homeTown,cash);
	}
	/**
	 * Create the standard map with all cities defined in {@link ECityName}
	 * @return standard map of the game
	 * @throws IOException Cities properties could not be read
	 */
	public static IMap createMap() throws IOException{
		ECityName[] cityNames = ECityName.values();
		ICity[] cities = new ICity[cityNames.length];
		for (int i = 0; i < cityNames.length; i++) {
			cities[i]=CityFactory.createCityByName(cityNames[i]);
		}
		return new GameMap(cities);
	}
	public static IGame createGame(IMap map, EObjective objective, Difficulty difficulty, EGameSpeed speed, int startYear){
		return new Game(map, objective, difficulty, speed, Date.getInstance(startYear));
	}
}
