package ch.sahits.game.openpatrician.model;

import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

import ch.sahits.game.openpatrician.model.city.ICity;
import ch.sahits.game.openpatrician.model.ship.IShip;

class Player implements IPlayer{

	private final String name;
	private final String lastName;
	private ICity homeTown;
	private final LinkedList<IShip> fleet;
	private final boolean male;
	private int cash;
	
	
	public Player(String name, String lastName, ICity homeTown, boolean male, int cash) {
		super();
		this.name = name;
		this.lastName = lastName;
		this.homeTown = homeTown;
		this.male = male;
		fleet = new LinkedList<IShip>();
		this.cash=cash;
	}

	@Override
	public String getName() {
		return name;
	}

	@Override
	public String getLastName() {
		return lastName;
	}

	@Override
	public ICity getHometown() {
		return homeTown;
	}

	@Override
	public List<IShip> getFleet() {
		return Collections.unmodifiableList(fleet);
	}

	@Override
	public boolean isMale() {
		return male;
	}

	@Override
	public void addShipp(IShip ship) {
		fleet.add(ship);
	}

	@Override
	public void removeShip(IShip ship) {
		fleet.remove(ship);
	}

	@Override
	public int getCash() {
		return cash;
	}
	/**
	 * Add or subtract some cash
	 * @param diff amount of money that is transferred
	 */
	@Override
	public void updateCash(int diff){
		cash += diff;
	}

}
