package ch.sahits.game.openpatrician.model.city;

import ch.sahits.game.openpatrician.model.product.AmountablePrice;
import ch.sahits.game.openpatrician.model.product.EWare;

/**
 * Model of a city.
 * @author Andi Hotz, (c) Sahits GmbH, 2011
 * Created on Sep 16, 2011
 *
 */
public interface ICity {
	/**
	 * Retrieve the unique ID of the city.
	 * @return
	 */
	public String getUniqueID();
	/**
	 * Retrieve the city type
	 * @return
	 */
	public EKontorType getKontorType();
	/**
	 * Retrieve the city name
	 * @return
	 */
	public String getName();
	/**
	 * Retrieve the current population of the city by class
	 * @param popclass
	 * @return
	 */
	public int getPopulation(EPopulationClass popclass);
	/**
	 * Set the population by class
	 * @param population
	 * @param popClass
	 */
	public void setPopulation(int population, EPopulationClass popClass);
	/**
	 * retrieve the total population of the city
	 * @return
	 */
	public int getPopulation();
	/**
	 * Retrieve the amount of ware in the city
	 * @param ware
	 * @return
	 */
	public AmountablePrice<EWare> getWare(EWare ware);
	/**
	 * Add or remove ware from the city. If the amount is negative it will be removed.
	 * If the full amount is not available only the available will be moved and returned.
	 * The amount is in the ware specific size.
	 * @param ware
	 * @param amount
	 * @return amount moved
	 */
	public int move(EWare ware, int amount);
	public abstract EWare[] getIneffectiveProduction();
	public abstract EWare[] getEffectiveProduction();

}
